==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/PrivilegeCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.CollectionPageNonEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.annotation.Function;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Privilege;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.PrivilegeRequest;
import microsoft.dynamics.crm.entity.request.RoleRequest;
import microsoft.dynamics.crm.entity.request.RoletemplateRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class PrivilegeCollectionRequest extends CollectionPageEntityRequest<Privilege, PrivilegeRequest>{

    protected ContextPath contextPath;

    public PrivilegeCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Privilege.class, cp -> new PrivilegeRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public RoletemplateCollectionRequest roletemplateprivileges_association() {
        return new RoletemplateCollectionRequest(contextPath.addSegment("roletemplateprivileges_association"), Optional.empty());
    }

    public RoletemplateRequest roletemplateprivileges_association(String roletemplateid) {
        return new RoletemplateRequest(contextPath.addSegment("roletemplateprivileges_association").addKeys(new NameValue(roletemplateid.toString())), Optional.empty());
    }

    public RoleCollectionRequest roleprivileges_association() {
        return new RoleCollectionRequest(contextPath.addSegment("roleprivileges_association"), Optional.empty());
    }

    public RoleRequest roleprivileges_association(String roleid) {
        return new RoleRequest(contextPath.addSegment("roleprivileges_association").addKeys(new NameValue(roleid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest privilege_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("Privilege_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest privilege_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("Privilege_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest privilege_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("Privilege_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest privilege_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("Privilege_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    @Function(name = "RetrievePrivilegeSet")
    @JsonIgnore
    public CollectionPageNonEntityRequest<Privilege> retrievePrivilegeSet() {
        Map<String, TypedObject> _parameters = ParameterMap.empty();
        return CollectionPageNonEntityRequest.forFunction(this.contextPath.addActionOrFunctionSegment("Microsoft.Dynamics.CRM.RetrievePrivilegeSet"), Privilege.class, _parameters, microsoft.dynamics.crm.schema.SchemaInfo.INSTANCE);
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/PrivilegeCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.CollectionPageNonEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.annotation.Function;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Privilege;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.PrivilegeRequest;
import microsoft.dynamics.crm.entity.request.RoleRequest;
import microsoft.dynamics.crm.entity.request.RoletemplateRequest;

public class PrivilegeCollectionRequest extends CollectionPageEntityRequest<Privilege, PrivilegeRequest>{

    protected ContextPath contextPath;

    public PrivilegeCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Privilege.class, cp -> new PrivilegeRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public RoletemplateCollectionRequest roletemplateprivileges_association() {
        return new RoletemplateCollectionRequest(contextPath.addSegment("roletemplateprivileges_association"), Optional.empty());
    }

    public RoletemplateRequest roletemplateprivileges_association(String roletemplateid) {
        return new RoletemplateRequest(contextPath.addSegment("roletemplateprivileges_association").addKeys(new NameValue(roletemplateid.toString())), Optional.empty());
    }

    public RoleCollectionRequest roleprivileges_association() {
        return new RoleCollectionRequest(contextPath.addSegment("roleprivileges_association"), Optional.empty());
    }

    public RoleRequest roleprivileges_association(String roleid) {
        return new RoleRequest(contextPath.addSegment("roleprivileges_association").addKeys(new NameValue(roleid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest privilege_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("Privilege_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest privilege_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("Privilege_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest privilege_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("Privilege_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest privilege_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("Privilege_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    @Function(name = "RetrievePrivilegeSet")
    @JsonIgnore
    public CollectionPageNonEntityRequest<Privilege> retrievePrivilegeSet() {
        Map<String, TypedObject> _parameters = ParameterMap.empty();
        return CollectionPageNonEntityRequest.forFunction(this.contextPath.addActionOrFunctionSegment("Microsoft.Dynamics.CRM.RetrievePrivilegeSet"), Privilege.class, _parameters);
    }

}
